summaryrefslogtreecommitdiffstats
path: root/noatun/modules/marquis/marquis.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'noatun/modules/marquis/marquis.cpp')
-rw-r--r--noatun/modules/marquis/marquis.cpp24
1 files changed, 12 insertions, 12 deletions
diff --git a/noatun/modules/marquis/marquis.cpp b/noatun/modules/marquis/marquis.cpp
index 29ca7364..15a298c3 100644
--- a/noatun/modules/marquis/marquis.cpp
+++ b/noatun/modules/marquis/marquis.cpp
@@ -78,9 +78,9 @@ Marquis::Marquis()
// for testing: uncomment this and use
// dcop `dcop | grep noatun` Marquis activateAction dynamicRestore
// and dynamicSave accordingly.
-// (void) new KAction("Restore", 0, this, SLOT( dynamicRestore() ), actionCollection(), "dynamicRestore" );
-// (void) new KAction("Save", 0, this, SLOT( dynamicSave() ), actionCollection(), "dynamicSave" );
- connect( napp, SIGNAL( saveYourself() ), SLOT( dynamicSave() ));
+// (void) new KAction("Restore", 0, this, TQT_SLOT( dynamicRestore() ), actionCollection(), "dynamicRestore" );
+// (void) new KAction("Save", 0, this, TQT_SLOT( dynamicSave() ), actionCollection(), "dynamicSave" );
+ connect( napp, TQT_SIGNAL( saveYourself() ), TQT_SLOT( dynamicSave() ));
}
Marquis::~Marquis()
@@ -93,7 +93,7 @@ void Marquis::restore(void)
dynamicRestore();
}
// unload every window, and save the config as QStringList of those loaded
void Marquis::saveSessionConfig(KConfig *c)
{
kdDebug(66666) << k_funcinfo << endl;
@@ -107,20 +107,20 @@ void Marquis::saveSessionConfig(KConfig *c)
if ( !player->current().isNull() )
{
KURL songURL = player->current().url();
- songURL.setPass( QString::null ); // don't save passwords
+ songURL.setPass( TQString::null ); // don't save passwords
c->writePathEntry("Current Song", songURL.url());
}
else
- c->writePathEntry("Current Song", QString::null);
+ c->writePathEntry("Current Song", TQString::null);
c->writeEntry("Current Position", player->getTime());
c->writeEntry("PlayStatus", getPlayStatus( player ));
// borrowed from Plugin config dialog
- QStringList specList;
+ TQStringList specList;
- QValueList<NoatunLibraryInfo> loaded = napp->libraryLoader()->loaded();
- for( QValueList<NoatunLibraryInfo>::Iterator i = loaded.begin(); i != loaded.end(); ++i)
+ TQValueList<NoatunLibraryInfo> loaded = napp->libraryLoader()->loaded();
+ for( TQValueList<NoatunLibraryInfo>::Iterator i = loaded.begin(); i != loaded.end(); ++i)
{
if(!specList.contains((*i).specfile)
&& napp->libraryLoader()->isLoaded((*i).specfile)
@@ -139,7 +139,7 @@ void Marquis::readSessionConfig(KConfig *c)
{
Player *player = napp->player();
- c->setGroup(QString::null);
+ c->setGroup(TQString::null);
// First set volume, then load modules, some module could start
// playback and that would be with 100% volume!
@@ -147,10 +147,10 @@ void Marquis::readSessionConfig(KConfig *c)
//player->setVolume( 0 );
player->loop( c->readNumEntry("Loop Style", (int) Player::None) );
- QStringList list = c->readListEntry("Loaded Plugins");
+ TQStringList list = c->readListEntry("Loaded Plugins");
/*
kdDebug(66666) << "Marquis::readSessionConfig()" << endl;
- for(QStringList::ConstIterator i=list.begin(); i!=list.end(); ++i)
+ for(TQStringList::ConstIterator i=list.begin(); i!=list.end(); ++i)
kdDebug(66666) << *i << endl;
kdDebug(66666) << "Marquis::readSessionConfig() there we go" << endl;
*/
@@ -93,7 +93,7 @@ void Marquis::restore(void)
dynamicRestore();
}
-// unload every window, and save the config as QStringList of those loaded
+// unload every window, and save the config as TQStringList of those loaded
void Marquis::saveSessionConfig(KConfig *c)
{